Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(343)

Unified Diff: content/shell/shell.h

Issue 9834092: Content shell: Use only public API. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/shell/DEPS ('k') | content/shell/shell.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/shell/shell.h
diff --git a/content/shell/shell.h b/content/shell/shell.h
index 3f1d436ef37f3044dcbb634fe80ac75bf94ab4c3..07221da89ffa7516d86de48f1a70a27746e00469 100644
--- a/content/shell/shell.h
+++ b/content/shell/shell.h
@@ -24,7 +24,7 @@ typedef struct _GtkToolItem GtkToolItem;
#endif
class GURL;
-class TabContents;
+class WebContents;
namespace content {
class BrowserContext;
@@ -53,7 +53,7 @@ class Shell : public WebContentsDelegate,
const GURL& url,
SiteInstance* site_instance,
int routing_id,
- TabContents* base_tab_contents);
+ WebContents* base_web_contents);
// Returns the Shell object corresponding to the given RenderViewHost.
static Shell* FromRenderViewHost(RenderViewHost* rvh);
@@ -61,7 +61,7 @@ class Shell : public WebContentsDelegate,
// Closes all windows and exits.
static void PlatformExit();
- TabContents* tab_contents() const { return tab_contents_.get(); }
+ WebContents* web_contents() const { return web_contents_.get(); }
// layoutTestController related methods.
void set_wait_until_done() { wait_until_done_ = true; }
@@ -79,10 +79,10 @@ class Shell : public WebContentsDelegate,
STOP_BUTTON
};
- explicit Shell(TabContents* tab_contents);
+ explicit Shell(WebContents* web_contents);
- // Helper to create a new Shell given a newly created TabContents.
- static Shell* CreateShell(TabContents* tab_contents);
+ // Helper to create a new Shell given a newly created WebContents.
+ static Shell* CreateShell(WebContents* web_contents);
// All the methods that begin with Platform need to be implemented by the
// platform specific Shell implementation.
@@ -90,7 +90,7 @@ class Shell : public WebContentsDelegate,
void PlatformCleanUp();
// Creates the main window GUI.
void PlatformCreateWindow(int width, int height);
// Links the TabContents into the newly created window.
void PlatformSetContents();
// Resize the content area and GUI.
void PlatformResizeSubViews();
@@ -139,7 +139,7 @@ class Shell : public WebContentsDelegate,
GObject*, guint, GdkModifierType);
#endif
- scoped_ptr<TabContents> tab_contents_;
+ scoped_ptr<WebContents> web_contents_;
// layoutTestController related variables.
bool wait_until_done_;
« no previous file with comments | « content/shell/DEPS ('k') | content/shell/shell.cc » ('j') | no next file with comments »
@@ -90,7 +90,7 @@ class Shell : public WebContentsDelegate,
// Creates the main window GUI.
void PlatformCreateWindow(int width, int height);
- // Links the TabContents into the newly created window.
+ // Links the WebContents into the newly created window.
void PlatformSetContents();
// Resize the content area and GUI.

Powered by Google App Engine
This is Rietveld 408576698